=========
Type Lens
=========

.. warning:: Pre-Release Alpha Stage

    Please note that ``type-lens`` is currently in a pre-release alpha stage of development. This means the library is still
    under active development, and its API is subject to change. We encourage developers to experiment with ``type-lens`` and
    provide feedback, but we recommend against using it in production environments until a stable release is available.

    Please see :doc:`releases` for more information on the stability policy.

Introduction
============

The ``type-lens`` library is cool.

Purpose
=======

``type-lens`` is built to do stuff.

.. toctree::
    :titlesonly:
    :caption: Documentation
    :hidden:

    usage/index
    reference/index

.. toctree::
    :titlesonly:
    :caption: Development
    :hidden:

    changelog
    contribution-guide
    Available Issues <https://github.com/search?q=user%3Alitestar-org+state%3Aopen+label%3A%22good+first+issue%22+++no%3Aassignee+repo%3A%22type-lens%22&type=issues>
    Code of Conduct <https://github.com/litestar-org/.github?tab=coc-ov-file#readme>
